@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgaJob.cpp 5466 2006-10-12 09:31:39Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: pgaJob.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgaJob.h - PostgreSQL Agent Job
@@ -97,7 +97,7 @@ void pgaJob::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *proper
 		else
 			properties->AppendItem(_("Running at"), _("Not currently running"));
 
-        properties->AppendItem(_("Comment"), GetComment());
+        properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
     }
 }
 
