@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmEditGrid.cpp 5703 2006-11-29 14:48:51Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: frmEditGrid.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmEditGrid.cpp - Edit Grid Box
@@ -75,7 +75,11 @@ BEGIN_EVENT_TABLE(frmEditGrid, pgFrame)
     EVT_GRID_EDITOR_SHOWN(      frmEditGrid::OnEditorShown)
     EVT_GRID_EDITOR_HIDDEN(     frmEditGrid::OnEditorHidden)
     EVT_GRID_LABEL_RIGHT_CLICK( frmEditGrid::OnLabelRightClick)
+#if wxCHECK_VERSION(2,8,0)
+    EVT_AUI_PANE_BUTTON(        frmEditGrid::OnAuiUpdate)
+#else
     EVT_AUI_PANEBUTTON(         frmEditGrid::OnAuiUpdate)
+#endif
 END_EVENT_TABLE()
 
 
@@ -877,13 +881,15 @@ void frmEditGrid::Go()
     }
 
     // Check we have access
-    if (connection->ExecuteScalar(wxT("SELECT 1 FROM ") + tableName) != wxT("1"))
+    if (connection->ExecuteScalar(wxT("SELECT count(*) FROM ") + tableName + wxT(" WHERE false")) == wxT(""))
         return;
 
     SetStatusText(_("Refreshing data, please wait."), 0);
 
     toolBar->EnableTool(MNU_REFRESH, false);
     viewMenu->Enable(MNU_REFRESH, false);
+    toolBar->EnableTool(MNU_OPTIONS, false);
+    viewMenu->Enable(MNU_OPTIONS, false);
 
     wxString qry=wxT("SELECT ");
     if (hasOids)
@@ -906,6 +912,8 @@ void frmEditGrid::Go()
         Abort();
         toolBar->EnableTool(MNU_REFRESH, true);
         viewMenu->Enable(MNU_REFRESH, true);
+        toolBar->EnableTool(MNU_OPTIONS, true);
+        viewMenu->Enable(MNU_OPTIONS, true);
         return;
     }
 
@@ -920,6 +928,8 @@ void frmEditGrid::Go()
     {
         toolBar->EnableTool(MNU_REFRESH, true);
         viewMenu->Enable(MNU_REFRESH, true);
+        toolBar->EnableTool(MNU_OPTIONS, true);
+        viewMenu->Enable(MNU_OPTIONS, true);
         return;
     }
 
@@ -928,6 +938,8 @@ void frmEditGrid::Go()
         Abort();
         toolBar->EnableTool(MNU_REFRESH, true);
         viewMenu->Enable(MNU_REFRESH, true);
+        toolBar->EnableTool(MNU_OPTIONS, true);
+        viewMenu->Enable(MNU_OPTIONS, true);
         return;
     }
     SetStatusText(wxString::Format(_("%d rows."), thread->DataSet()->NumRows()), 0);
@@ -944,6 +956,8 @@ void frmEditGrid::Go()
 
     toolBar->EnableTool(MNU_REFRESH, true);
     viewMenu->Enable(MNU_REFRESH, true);
+    toolBar->EnableTool(MNU_OPTIONS, true);
+    viewMenu->Enable(MNU_OPTIONS, true);
 
     manager.Update();
 
