@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmQuery.cpp 5706 2006-11-29 16:31:42Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: frmQuery.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmQuery.cpp - SQL Query Box
@@ -65,7 +65,7 @@ BEGIN_EVENT_TABLE(frmQuery, pgFrame)
     EVT_COMBOBOX(CTRLID_CONNECTION, frmQuery::OnChangeConnection)
     EVT_CLOSE(                      frmQuery::OnClose)
     EVT_SET_FOCUS(                  frmQuery::OnSetFocus)
-    EVT_MENU(MNU_NEW,                frmQuery::OnNew)
+    EVT_MENU(MNU_NEW,               frmQuery::OnNew)
     EVT_MENU(MNU_OPEN,              frmQuery::OnOpen)
     EVT_MENU(MNU_SAVE,              frmQuery::OnSave)
     EVT_MENU(MNU_SAVEAS,            frmQuery::OnSaveAs)
@@ -87,7 +87,7 @@ BEGIN_EVENT_TABLE(frmQuery, pgFrame)
     EVT_MENU(MNU_HELP,              frmQuery::OnHelp)
     EVT_MENU(MNU_CLEARHISTORY,      frmQuery::OnClearHistory)
     EVT_MENU(MNU_SAVEHISTORY,       frmQuery::OnSaveHistory)
-    EVT_MENU(MNU_SELECTALL,            frmQuery::OnSelectAll)
+    EVT_MENU(MNU_SELECTALL,         frmQuery::OnSelectAll)
     EVT_MENU(MNU_QUICKREPORT,       frmQuery::OnQuickReport)
     EVT_MENU(MNU_WORDWRAP,          frmQuery::OnWordWrap)
     EVT_MENU(MNU_SHOWWHITESPACE,    frmQuery::OnShowWhitespace)
@@ -103,7 +103,11 @@ BEGIN_EVENT_TABLE(frmQuery, pgFrame)
     EVT_ACTIVATE(                   frmQuery::OnActivate)
     EVT_STC_MODIFIED(CTL_SQLQUERY,  frmQuery::OnChangeStc)
     EVT_STC_UPDATEUI(CTL_SQLQUERY,  frmQuery::OnPositionStc)
+#if wxCHECK_VERSION(2,8,0)
+    EVT_AUI_PANE_CLOSE(             frmQuery::OnAuiUpdate)
+#else
     EVT_AUI_PANECLOSE(              frmQuery::OnAuiUpdate)
+#endif
 END_EVENT_TABLE()
 
 frmQuery::frmQuery(frmMain *form, const wxString& _title, pgConn *_conn, const wxString& query)
@@ -632,6 +636,10 @@ void frmQuery::OnContents(wxCommandEvent& event)
 
 void frmQuery::OnChangeConnection(wxCommandEvent &ev)
 {
+    // On Solaris, this event seems to get fired when the form closes(!!)
+    if(!IsVisible())
+        return; 
+
     unsigned int sel=cbConnection->GetCurrentSelection();
     if (sel == cbConnection->GetCount()-1)
     {
