@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgTable.h 5466 2006-10-12 09:31:39Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgTable.h 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgTable.h - Table property 
@@ -65,8 +65,8 @@ private:
     wxString AppendNum(bool &changed, wxTextCtrl *ctl, double val);
 
     bool tableVacEnabled, hasVacuum;
-    long settingVacBaseThr, settingAnlBaseThr, settingCostDelay, settingCostLimit;
-    long tableVacBaseThr, tableAnlBaseThr, tableCostDelay, tableCostLimit;
+    long settingVacBaseThr, settingAnlBaseThr, settingCostDelay, settingCostLimit, settingFreezeMinAge, settingFreezeMaxAge;
+    long tableVacBaseThr, tableAnlBaseThr, tableCostDelay, tableCostLimit, tableFreezeMinAge, tableFreezeMaxAge;
     double settingVacFactor, settingAnlFactor;
     double tableVacFactor, tableAnlFactor;
 
