@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgCast.cpp 5466 2006-10-12 09:31:39Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: pgCast.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgCast.cpp - Cast class
@@ -72,7 +72,7 @@ void pgCast::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *proper
         properties->AppendItem(_("Context"), GetCastContext());
         properties->AppendItem(_("System cast?"), GetSystemObject());
         if (GetConnection()->BackendMinimumVersion(7, 5))
-            properties->AppendItem(_("Comment"), GetComment());
+            properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
     }
 }
 
