@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgIndex.cpp 5697 2006-11-28 09:36:10Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: pgIndex.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgIndex.cpp - Index class
@@ -217,7 +217,7 @@ void pgIndexBase::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *p
         properties->AppendItem(_("Access method"), GetIndexType());
         properties->AppendItem(_("Constraint"), GetConstraint());
         properties->AppendItem(_("System index?"), GetSystemObject());
-        properties->AppendItem(_("Comment"), GetComment());
+        properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
     }
 }
 
