@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTable.cpp 5506 2006-10-20 16:09:57Z dpage $
-// Copyright (C) 2002 - 2006, The pgAdmin Development Team
+// RCS-ID:      $Id: pgTable.cpp 5827 2007-01-04 16:35:14Z dpage $
+// Copyright (C) 2002 - 2007, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgTable.cpp - Table class
@@ -181,7 +181,11 @@ wxString pgTable::GetSql(ctlTree *browser)
                     {
                         sql += wxT(",");
                         if (!prevComment.IsEmpty())
+                        {
                             sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
+                            if (prevComment.BeforeFirst('\n').Length() != prevComment.Length())
+                                sql += wxT("...");
+                        }
 
                         sql += wxT("\n");
                     }
@@ -220,7 +224,12 @@ wxString pgTable::GetSql(ctlTree *browser)
                 sql += wxT(",");
 
                 if (!prevComment.IsEmpty())
+                {
                     sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
+                    if (prevComment.BeforeFirst('\n').Length() != prevComment.Length())
+                        sql += wxT("...");
+                }
+
 
                 sql += wxT("\n  CONSTRAINT ") + data->GetQuotedIdentifier() 
                     + wxT(" ") + data->GetTypeName().Upper() 
@@ -244,7 +253,12 @@ wxString pgTable::GetSql(ctlTree *browser)
             }
         }
         if (!prevComment.IsEmpty())
+       {
             sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
+            if (prevComment.BeforeFirst('\n').Length() != prevComment.Length())
+                sql += wxT("...");
+       }
+
 
         sql += wxT("\n) ");
         if (GetInheritedTableCount())
@@ -558,7 +572,7 @@ void pgTable::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prope
             properties->AppendItem(_("Inherited tables"), GetInheritedTables());
         properties->AppendItem(_("Has OIDs?"), GetHasOids());
         properties->AppendItem(_("System table?"), GetSystemObject());
-        properties->AppendItem(_("Comment"), GetComment());
+        properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
 
     }
     if (form && GetVacuumHint() && !hintShown)
