@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAgent - PostgreSQL Tools
-// $Id: misc.h 4874 2006-01-06 17:33:27Z dpage $
-// Copyright (C) 2003 - 2006 The pgAdmin Development Team
+// $Id: misc.h 5013 2006-02-21 09:39:15Z dpage $
+// Copyright (C) 2002 - 2006 The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // misc.h - misc functions
@@ -15,10 +15,10 @@
 
 
 void WaitAWhile(const bool waitLong=false);
-void setOptions(int argc, char **argv);
+void setOptions(int argc, char **argv, const wxString& executable);
 wxString getArg(int &argc, char** &argv);
 wxString NumToStr(const long l);
-wxString qtString(const wxString& value);
+wxString qtDbString(const wxString& value);
 
 #endif // MISC_H
 
